@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use Catalyst qw/
-    Config::YAML::XS
+    ConfigLoader
     Static::Simple
     Authentication
     Cache
@@ -18,10 +18,9 @@ use Catalyst qw/
     +Foorum::Plugin::FoorumUtils
     /;
 
-our $VERSION = '1.000003';
+our $VERSION = '1.000004';
 
 __PACKAGE__->config( { VERSION => $VERSION } );
-__PACKAGE__->config( 'config_file' => [ 'foorum.yml', 'foorum_local.yml' ] );
 
 __PACKAGE__->setup();
 
